<?php

namespace App\Http\Controllers;

use App\Models\AuctionDetail;
use App\Models\AuctionItem;
use App\Models\EAuction;
use App\Models\CompanyAuctionRate;

use Carbon\Carbon;
use DateTime;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class EAuctionController extends Controller
{
    public function __construct( )
    {
        $this->middleware('auth');  
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    
    public function index()
    {
        $tenders = EAuction::orderBy('id', 'desc')->get();

        
        return view('admin/e-auction/index',compact('tenders'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $auction_items = AuctionItem::all(); 
          
        return view('admin/e-auction/create', compact('auction_items' ));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        try {
            DB::beginTransaction();
            $AuctionData =$request->Auction;  
            $AuctionDetailData =$request->AuctionDetail;
            $auction = EAuction::create($AuctionData);
            $e_auction_id = $auction->id;
            $auction->update(['tender_no' => sprintf("%04d",  $e_auction_id)]);

            foreach ($AuctionDetailData as  $value) { 
                $value['e_auction_id'] = $e_auction_id;
                AuctionDetail::create($value);
            }

            DB::commit(); 
            return redirect('e-auction')->with('success', 'Auction created.');
        } catch (\Throwable $th) { 
            DB::rollback(); 
            return redirect()->back()->with('error', $th->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\EAuction  $eAuction
     * @return \Illuminate\Http\Response
     */
    public function show( $id )
    {
        try {
            $temp_score = [];
            $e_auction = EAuction::with('companies')->where('id',(decrypt($id)))->first();
            $auction_items  = $e_auction->getEAuctionItems;

//           
            return view('admin.e-auction.show', compact('auction_items', 'e_auction'));
        } catch (\Throwable $th) { 
            DB::rollback(); 
            dd($th->getMessage());
            return redirect()->back()->with('error', $th->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\EAuction  $eAuction
     * @return \Illuminate\Http\Response
     */
    
    public function closeAuction( Request $request )
    {     
       
        $this->validate($request,[ 
            'opening_date'=>'required|date_format:Y-m-d',
            'opening_time'=>'required|date_format:H:i',  
        ]);

        try {  
                $id = decrypt( $request->id) ;
                 
                $data =  $request->except('id') ;
                DB::beginTransaction();
             
                $tender = EAuction::find($id)->update($data); 
                
                DB::commit();
                return response()->json(['status' => true, 'success' =>true, 'msg' => "Success" ]);
        }catch (\Exception $e){
            DB::rollback();
            return response()->json(['status' => false, 'success' =>false, 'msg' => $e->getMessage()]);
        } 
    }

     
    public function openAuction( $status, $auction_id )
    {       
        try {  
                $id = decrypt( $auction_id) ; 
                DB::beginTransaction(); 
                    $tender = EAuction::find($id);
                    $opening_date = $tender->opening_date;
                    $opening_time = $tender->opening_time; 
                    date_default_timezone_set("Asia/Karachi");
                    $date = new DateTime(); 
                    $current_date_time = date("Y-m-d H:i:s");
                    
                    $opening_date_time = $opening_date.' '.$opening_time;
                     
                    $to = Carbon::createFromFormat('Y-m-d H:i:s', $opening_date_time);
                    $from = Carbon::createFromFormat('Y-m-d H:i:s', $current_date_time);

                    $total_seconds = $to->diffInSeconds($from);
  
                    $hours = floor($total_seconds / 3600);
                    $minutes = floor(($total_seconds / 60) % 60);
                    $seconds = $total_seconds % 60;

                    if( $current_date_time >= $opening_date_time ):
                        $tender->update(['tender_status' => $status]);
                        
                        $status = "open";
                        $message =  "<p>Please wait....</p><p>\r\n system is opening auction detail page.</p>";
                        $auction_id = $auction_id;
                    else: 
                        $message = "Not allowed. You can open this auction after ".$hours .' hours, '.$minutes.' minutes and '.$seconds.' seconds'; 
                        $status = "close";
                        $auction_id = null;
                    endif;
 
                DB::commit();
                return response()->json(['status' => $status, 'success' =>true, 'msg' => $message, 'auction_id' => $auction_id ]);
        }catch (\Exception $e){
            DB::rollback();
            return response()->json(['status' => false, 'success' =>false, 'msg' => $e->getMessage()]);
        } 
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\EAuction  $eAuction
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, EAuction $eAuction)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\EAuction  $eAuction
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request, $id)
    {
    
        try {

         DB::beginTransaction();
            AuctionItem::find($id)->delete();
            DB::commit();
            return response()->json(['status' => true, 'msg' => 'Record has been deleted']);

        } catch (\Exception $e) {
            DB::rollback();
            return response()->json(['status' => false, 'msg' => $e->getMessage()]);
        }
    }
    public function print($id)
    {
        try {

            $e_auction = EAuction::findOrFail(decrypt($id));
            $auction_items  = $e_auction->getEAuctionItems;
            $print_type = "";
            
            return view('print.e-auction', compact('auction_items', 'e_auction', 'print_type'));
        } catch (\Throwable $th) {  
            // dd($th->getMessage());
            return redirect()->back()->with('error', $th->getMessage());
        }
    }
}
